@@ -58,6 +58,7 @@ from .type_defs import (
     DomainInformationTypeDef,
     EBSOptionsTypeDef,
     ElasticsearchClusterConfigTypeDef,
+    EmptyResponseMetadataTypeDef,
     EncryptionAtRestOptionsTypeDef,
     FilterTypeDef,
     GetCompatibleElasticsearchVersionsResponseTypeDef,
@@ -144,7 +145,7 @@ class ElasticsearchServiceClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#accept_inbound_cross_cluster_search_connection)
         """
 
-    def add_tags(self, *, ARN: str, TagList: Sequence["TagTypeDef"]) -> None:
+    def add_tags(self, *, ARN: str, TagList: Sequence[TagTypeDef]) -> EmptyResponseMetadataTypeDef:
         """
         Attaches tags to an existing Elasticsearch domain.
 
@@ -180,25 +181,33 @@ class ElasticsearchServiceClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#cancel_elasticsearch_service_software_update)
         """
 
+    def close(self) -> None:
+        """
+        Closes underlying endpoint connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Client.close)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#close)
+        """
+
     def create_elasticsearch_domain(
         self,
         *,
         DomainName: str,
         ElasticsearchVersion: str = ...,
-        ElasticsearchClusterConfig: "ElasticsearchClusterConfigTypeDef" = ...,
-        EBSOptions: "EBSOptionsTypeDef" = ...,
+        ElasticsearchClusterConfig: ElasticsearchClusterConfigTypeDef = ...,
+        EBSOptions: EBSOptionsTypeDef = ...,
         AccessPolicies: str = ...,
-        SnapshotOptions: "SnapshotOptionsTypeDef" = ...,
-        VPCOptions: "VPCOptionsTypeDef" = ...,
-        CognitoOptions: "CognitoOptionsTypeDef" = ...,
-        EncryptionAtRestOptions: "EncryptionAtRestOptionsTypeDef" = ...,
-        NodeToNodeEncryptionOptions: "NodeToNodeEncryptionOptionsTypeDef" = ...,
+        SnapshotOptions: SnapshotOptionsTypeDef = ...,
+        VPCOptions: VPCOptionsTypeDef = ...,
+        CognitoOptions: CognitoOptionsTypeDef = ...,
+        EncryptionAtRestOptions: EncryptionAtRestOptionsTypeDef = ...,
+        NodeToNodeEncryptionOptions: NodeToNodeEncryptionOptionsTypeDef = ...,
         AdvancedOptions: Mapping[str, str] = ...,
-        LogPublishingOptions: Mapping[LogTypeType, "LogPublishingOptionTypeDef"] = ...,
-        DomainEndpointOptions: "DomainEndpointOptionsTypeDef" = ...,
-        AdvancedSecurityOptions: "AdvancedSecurityOptionsInputTypeDef" = ...,
-        AutoTuneOptions: "AutoTuneOptionsInputTypeDef" = ...,
-        TagList: Sequence["TagTypeDef"] = ...
+        LogPublishingOptions: Mapping[LogTypeType, LogPublishingOptionTypeDef] = ...,
+        DomainEndpointOptions: DomainEndpointOptionsTypeDef = ...,
+        AdvancedSecurityOptions: AdvancedSecurityOptionsInputTypeDef = ...,
+        AutoTuneOptions: AutoTuneOptionsInputTypeDef = ...,
+        TagList: Sequence[TagTypeDef] = ...
     ) -> CreateElasticsearchDomainResponseTypeDef:
         """
         Creates a new Elasticsearch domain.
@@ -210,8 +219,8 @@ class ElasticsearchServiceClient(BaseClient):
     def create_outbound_cross_cluster_search_connection(
         self,
         *,
-        SourceDomainInfo: "DomainInformationTypeDef",
-        DestinationDomainInfo: "DomainInformationTypeDef",
+        SourceDomainInfo: DomainInformationTypeDef,
+        DestinationDomainInfo: DomainInformationTypeDef,
         ConnectionAlias: str
     ) -> CreateOutboundCrossClusterSearchConnectionResponseTypeDef:
         """
@@ -227,7 +236,7 @@ class ElasticsearchServiceClient(BaseClient):
         *,
         PackageName: str,
         PackageType: Literal["TXT-DICTIONARY"],
-        PackageSource: "PackageSourceTypeDef",
+        PackageSource: PackageSourceTypeDef,
         PackageDescription: str = ...
     ) -> CreatePackageResponseTypeDef:
         """
@@ -247,7 +256,7 @@ class ElasticsearchServiceClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#delete_elasticsearch_domain)
         """
 
-    def delete_elasticsearch_service_role(self) -> None:
+    def delete_elasticsearch_service_role(self) -> EmptyResponseMetadataTypeDef:
         """
         Deletes the service-linked role that Elasticsearch Service uses to manage and
         maintain VPC domains.
@@ -357,11 +366,7 @@ class ElasticsearchServiceClient(BaseClient):
         """
 
     def describe_inbound_cross_cluster_search_connections(
-        self,
-        *,
-        Filters: Sequence["FilterTypeDef"] = ...,
-        MaxResults: int = ...,
-        NextToken: str = ...
+        self, *, Filters: Sequence[FilterTypeDef] = ..., MaxResults: int = ..., NextToken: str = ...
     ) -> DescribeInboundCrossClusterSearchConnectionsResponseTypeDef:
         """
         Lists all the inbound cross-cluster search connections for a destination domain.
@@ -371,11 +376,7 @@ class ElasticsearchServiceClient(BaseClient):
         """
 
     def describe_outbound_cross_cluster_search_connections(
-        self,
-        *,
-        Filters: Sequence["FilterTypeDef"] = ...,
-        MaxResults: int = ...,
-        NextToken: str = ...
+        self, *, Filters: Sequence[FilterTypeDef] = ..., MaxResults: int = ..., NextToken: str = ...
     ) -> DescribeOutboundCrossClusterSearchConnectionsResponseTypeDef:
         """
         Lists all the outbound cross-cluster search connections for a source domain.
@@ -387,7 +388,7 @@ class ElasticsearchServiceClient(BaseClient):
     def describe_packages(
         self,
         *,
-        Filters: Sequence["DescribePackagesFilterTypeDef"] = ...,
+        Filters: Sequence[DescribePackagesFilterTypeDef] = ...,
         MaxResults: int = ...,
         NextToken: str = ...
     ) -> DescribePackagesResponseTypeDef:
@@ -583,7 +584,7 @@ class ElasticsearchServiceClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#reject_inbound_cross_cluster_search_connection)
         """
 
-    def remove_tags(self, *, ARN: str, TagKeys: Sequence[str]) -> None:
+    def remove_tags(self, *, ARN: str, TagKeys: Sequence[str]) -> EmptyResponseMetadataTypeDef:
         """
         Removes the specified set of tags from the specified Elasticsearch domain.
 
@@ -605,19 +606,19 @@ class ElasticsearchServiceClient(BaseClient):
         self,
         *,
         DomainName: str,
-        ElasticsearchClusterConfig: "ElasticsearchClusterConfigTypeDef" = ...,
-        EBSOptions: "EBSOptionsTypeDef" = ...,
-        SnapshotOptions: "SnapshotOptionsTypeDef" = ...,
-        VPCOptions: "VPCOptionsTypeDef" = ...,
-        CognitoOptions: "CognitoOptionsTypeDef" = ...,
+        ElasticsearchClusterConfig: ElasticsearchClusterConfigTypeDef = ...,
+        EBSOptions: EBSOptionsTypeDef = ...,
+        SnapshotOptions: SnapshotOptionsTypeDef = ...,
+        VPCOptions: VPCOptionsTypeDef = ...,
+        CognitoOptions: CognitoOptionsTypeDef = ...,
         AdvancedOptions: Mapping[str, str] = ...,
         AccessPolicies: str = ...,
-        LogPublishingOptions: Mapping[LogTypeType, "LogPublishingOptionTypeDef"] = ...,
-        DomainEndpointOptions: "DomainEndpointOptionsTypeDef" = ...,
-        AdvancedSecurityOptions: "AdvancedSecurityOptionsInputTypeDef" = ...,
-        NodeToNodeEncryptionOptions: "NodeToNodeEncryptionOptionsTypeDef" = ...,
-        EncryptionAtRestOptions: "EncryptionAtRestOptionsTypeDef" = ...,
-        AutoTuneOptions: "AutoTuneOptionsTypeDef" = ...,
+        LogPublishingOptions: Mapping[LogTypeType, LogPublishingOptionTypeDef] = ...,
+        DomainEndpointOptions: DomainEndpointOptionsTypeDef = ...,
+        AdvancedSecurityOptions: AdvancedSecurityOptionsInputTypeDef = ...,
+        NodeToNodeEncryptionOptions: NodeToNodeEncryptionOptionsTypeDef = ...,
+        EncryptionAtRestOptions: EncryptionAtRestOptionsTypeDef = ...,
+        AutoTuneOptions: AutoTuneOptionsTypeDef = ...,
         DryRun: bool = ...
     ) -> UpdateElasticsearchDomainConfigResponseTypeDef:
         """
@@ -632,7 +633,7 @@ class ElasticsearchServiceClient(BaseClient):
         self,
         *,
         PackageID: str,
-        PackageSource: "PackageSourceTypeDef",
+        PackageSource: PackageSourceTypeDef,
         PackageDescription: str = ...,
         CommitMessage: str = ...
     ) -> UpdatePackageResponseTypeDef:
