@@ -29,8 +29,7 @@ Usage::
 """
 from typing import Generic, Iterator, TypeVar
 
-from botocore.paginate import PageIterator
-from botocore.paginate import Paginator as Boto3Paginator
+from botocore.paginate import PageIterator, Paginator
 
 from .type_defs import (
     DescribeReservedElasticsearchInstanceOfferingsResponseTypeDef,
@@ -60,7 +59,7 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
         """
 
 
-class DescribeReservedElasticsearchInstanceOfferingsPaginator(Boto3Paginator):
+class DescribeReservedElasticsearchInstanceOfferingsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Paginator.DescribeReservedElasticsearchInstanceOfferings)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/paginators/#describereservedelasticsearchinstanceofferingspaginator)
@@ -70,7 +69,7 @@ class DescribeReservedElasticsearchInstanceOfferingsPaginator(Boto3Paginator):
         self,
         *,
         ReservedElasticsearchInstanceOfferingId: str = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeReservedElasticsearchInstanceOfferingsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Paginator.DescribeReservedElasticsearchInstanceOfferings.paginate)
@@ -78,7 +77,7 @@ class DescribeReservedElasticsearchInstanceOfferingsPaginator(Boto3Paginator):
         """
 
 
-class DescribeReservedElasticsearchInstancesPaginator(Boto3Paginator):
+class DescribeReservedElasticsearchInstancesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Paginator.DescribeReservedElasticsearchInstances)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/paginators/#describereservedelasticsearchinstancespaginator)
@@ -88,7 +87,7 @@ class DescribeReservedElasticsearchInstancesPaginator(Boto3Paginator):
         self,
         *,
         ReservedElasticsearchInstanceId: str = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeReservedElasticsearchInstancesResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Paginator.DescribeReservedElasticsearchInstances.paginate)
@@ -96,14 +95,14 @@ class DescribeReservedElasticsearchInstancesPaginator(Boto3Paginator):
         """
 
 
-class GetUpgradeHistoryPaginator(Boto3Paginator):
+class GetUpgradeHistoryPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Paginator.GetUpgradeHistory)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/paginators/#getupgradehistorypaginator)
     """
 
     def paginate(
-        self, *, DomainName: str, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, DomainName: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[GetUpgradeHistoryResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Paginator.GetUpgradeHistory.paginate)
@@ -111,7 +110,7 @@ class GetUpgradeHistoryPaginator(Boto3Paginator):
         """
 
 
-class ListElasticsearchInstanceTypesPaginator(Boto3Paginator):
+class ListElasticsearchInstanceTypesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Paginator.ListElasticsearchInstanceTypes)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/paginators/#listelasticsearchinstancetypespaginator)
@@ -122,7 +121,7 @@ class ListElasticsearchInstanceTypesPaginator(Boto3Paginator):
         *,
         ElasticsearchVersion: str,
         DomainName: str = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListElasticsearchInstanceTypesResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Paginator.ListElasticsearchInstanceTypes.paginate)
@@ -130,14 +129,14 @@ class ListElasticsearchInstanceTypesPaginator(Boto3Paginator):
         """
 
 
-class ListElasticsearchVersionsPaginator(Boto3Paginator):
+class ListElasticsearchVersionsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Paginator.ListElasticsearchVersions)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/paginators/#listelasticsearchversionspaginator)
     """
 
     def paginate(
-        self, *, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListElasticsearchVersionsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Paginator.ListElasticsearchVersions.paginate)
